Development - Betty documentation

Hide navigation sidebar
Hide table of contents sidebar
Skip to content
Back to top
View this page
Toggle table of contents sidebar

# Development

This section covers how to develop Betty itself.

See also

Read Contributing to Betty if you would like to share your improvements to Betty with the wider community.

## Getting started

Install Betty from source.

## In this section

- Developing a Betty extension

- Working on Betty’s translations

- Testing Betty’s source code